@@ -59,10 +59,10 @@ def get_image_filename(self, code, format, options, prefix='blockdiag'):
 
     if format.upper() == 'PDF':
         try:
-            import reportlab
+            __import__("reportlab")
         except ImportError:
             msg = 'blockdiag error:\n' + \
-                  'colud not output PDF format; Install reportlab\n'
+                  'could not output PDF format; Install reportlab\n'
             raise BlockdiagError(msg)
 
     hashkey = (code + str(options)).encode('utf-8')
@@ -135,7 +135,7 @@ def resolve_reference(self, href, options):
     pattern = re.compile(u("^:ref:`(.+?)`"), re.UNICODE)
     matched = pattern.search(href)
     if matched:
-        return get_anchor(self, matched.group(1), options['current_docname'])
+        return get_anchor(self, matched.group(1), options.get('current_docname', ''))
     else:
         return href
 
@@ -303,7 +303,7 @@ def latex_visit_blockdiag(self, node):
 
 
 def on_doctree_resolved(self, doctree, docname):
-    if self.builder.name in ('gettext', 'singlehtml', 'html', 'latex', 'epub'):
+    if self.builder.format in ('html', 'latex'):
         return
 
     for node in doctree.traverse(blockdiag.utils.rst.nodes.blockdiag):
@@ -318,7 +318,7 @@ def on_doctree_resolved(self, doctree, docname):
             image.draw()
             image.save()
 
-        candidates = {'image/png': outfn}
+        candidates = {'image/png': relfn}
         image = nodes.image(uri=outfn, candidates=candidates)
         node.parent.replace(node, image)
 
